@@ -17,7 +17,7 @@ from PySide6.QtWidgets import *
 from ..events import *
 from ..lang import Translator
 from ..tomlfile import *
-from ..types import CommentValue
+from ..utils import DeferredCallable
 
 
 class Theme:
@@ -49,6 +49,7 @@ class GetterApp(QApplication):
         self.themes:          dict[str, Theme] = {}  # PyCharm detects this as a dict[str, str], despite explicit type hints.
         self.theme_index_map: dict[str, int] = {}
 
+        EventBus['settings'] = self.settings.event_bus
         EventBus['settings'].subscribe(DeferredCallable(self.load_themes), TomlEvents.Reload)
         EventBus['settings'].subscribe(DeferredCallable(self.update_stylesheet), TomlEvents.Set,
                                        event_predicate=lambda event: event.key == 'gui/themes/selected')
