@@ -23,6 +23,7 @@ from ..client import HTTP_CODE_MAP
 from ..constants import *
 from ..events import *
 from ..tomlfile import TomlFile, TomlEvents
+from ..utils import DeferredCallable
 from .app import *
 from .menus import *
 from .utils import scroll_to_top
@@ -50,8 +51,8 @@ class SettingsWindow(QWidget):
         # Create a self.translator DeferredCallable with every tuple acting as arguments.
         EventBus['settings'].subscribe(DeferredCallable(
             QMessageBox.warning, self, *(DeferredCallable(self.translator, *key) for key in (
-                ('warnings.settings.import_failure.title',), ('warnings.settings.import_failure.description', self.settings.path)))
-        ), TomlEvents.Fail, event_predicate=lambda event: event.failure == 'import')
+                ('warnings.settings.import_failure.title',), ('warnings.settings.import_failure.description', self.settings.path)))),
+            TomlEvents.Fail, event_predicate=lambda event: event.failure == 'import')
 
         self.theme_dropdown:          QComboBox
         self.aspect_ratio_dropdown:   QComboBox
@@ -362,7 +363,7 @@ class AppWindow(QMainWindow):
                                                                         self.media_frame, toggle_media_detach,
                                                                         self.APP.translator('gui.outputs.image.detached'))
                 self.image_detach_button.setText(self.APP.translator('gui.outputs.reattach'))
-                window.resizeEvent = lambda *_: self.resize_image()
+                window.resizeEvent = DeferredCallable(self.resize_image)
                 window.show()
             else:
                 window = self.detached['media']
@@ -562,18 +563,20 @@ class AppWindow(QMainWindow):
         if not user_input:
             return
 
-        if '/file/' not in user_input:
-            if user_input.endswith(('png', 'jpg', 'jpeg', 'webp', 'gif')):
-                user_input = f'images/file/{user_input}'
-            else:
-                user_input = f'progression/file/{user_input}'
+        search_path = user_input.strip()
 
-        if user_input:
+        if '/file/' not in user_input:
+            if search_path.endswith(('png', 'jpg', 'jpeg', 'webp', 'gif')):
+                search_path = f'images/file/{search_path}'
+            else:
+                search_path = f'progression/file/{search_path}'
+
+        if search_path:
             if scan:
-                self.client.recursive_search(user_input)
+                self.client.recursive_search(search_path)
                 self.use_input()
             else:
-                data = self.client.get_hi_data(user_input)
+                data = self.client.get_hi_data(search_path)
                 if isinstance(data, bytes):
                     self.clear_picture.setDisabled(False)
                     self.copy_picture.setDisabled(False)
@@ -592,7 +595,12 @@ class AppWindow(QMainWindow):
                     if isinstance(data, dict):
                         data = json.dumps(data, indent=2)
                     elif isinstance(data, int):
-                        data = f'{data}: {HTTP_CODE_MAP[data][0]}\n{HTTP_CODE_MAP[data][1]}'
+                        data = (
+                            f'Could not get resource at:\n'
+                            f'{self.client.api_root}{search_path}\n\n'
+                            f'{data}: {HTTP_CODE_MAP[data][0]}\n'
+                            f'{HTTP_CODE_MAP[data][1]}'
+                        )
 
                     output = data
                     replaced = set()
