@@ -6,9 +6,11 @@
 __all__ = (
     'BetterTomlDecoder',
     'BetterTomlEncoder',
+    'CommentValue',
     'make_comment_val',
     'TomlFile',
     'TomlEvents',
+    'TOML_VALUE',
 )
 
 import warnings
@@ -16,16 +18,19 @@ from pathlib import Path
 from pathlib import PurePath
 from typing import Any
 from typing import Final
+from typing import TypeAlias
 
 import toml.decoder
 import toml.encoder
+from toml.decoder import CommentValue
 
 from .events import *
-from .types import CommentValue
-from .types import TOML_VALUE
 
 SPECIAL_PATH_PREFIX: Final[str] = '$PATH$|'
 
+TOML_VALUE: TypeAlias = dict | list | float | int | str | bool | PurePath
+"""Represents a possible TOML value, with :py:class:`dict` being a Table, and :py:class:`list` being an Array."""
+
 
 class TomlEvents:
     """Namespace for all events relating to :py:class:`TomlFile` objects."""
@@ -33,7 +38,7 @@ class TomlEvents:
         """Generic event for TomlFiles"""
         __slots__ = ('toml_file',)
 
-        def __init__(self, toml_file: 'TomlFile'):
+        def __init__(self, toml_file: 'TomlFile') -> None:
             self.toml_file = toml_file
 
     class File(TomlEvent):
@@ -56,44 +61,50 @@ class TomlEvents:
         """Saving a TomlFile to disk."""
         __slots__ = ('toml_file',)
 
-    class Get(TomlEvent):
-        """Value is accessed."""
-        __slots__ = ('toml_file', 'key', 'value')
+    class KeyAccess(TomlEvent):
+        """A key's value is accessed."""
+        __slots__ = ('toml_file', 'key')
 
-        def __init__(self, toml_file: 'TomlFile', key: str, value: TOML_VALUE | None):
+        def __init__(self, toml_file: 'TomlFile', key: str | None) -> None:
             super().__init__(toml_file=toml_file)
-            self.key = key
-            self.value = value
+            self.key: str = self._Key(key)
 
-    class Set(TomlEvent):
-        """Value is set."""
-        __slots__ = ('toml_file', 'key', 'old', 'new')
-
-        class _SetKey(str):
+        class _Key(str):
             """Proxy for a key :py:class:`str`.
 
             If key was none, act as a wildcard for :py:class:`str` comparisons
             """
             __slots__ = ('toml_file', 'key', 'wildcard')
 
-            def __new__(cls, key: str | None):
+            def __new__(cls, key: str | None) -> 'TomlEvents.KeyAccess._Key':
                 o = super().__new__(cls, key if key is not None else '%WILDCARD%')
                 return o
 
-            def __init__(self, key: str | None):
+            def __init__(self, key: str | None) -> None:
                 super().__init__()
-                self.key:      str = key
+                self.key:      str | None = key
                 self.wildcard: bool = key is None
 
-            def __bool__(self):
-                return self.wildcard or self.key
+            def __bool__(self) -> bool:
+                return bool(self.wildcard or self.key)
 
-            def __eq__(self, other: Any):
+            def __eq__(self, other: Any) -> bool:
                 return self.wildcard or self.key == other
 
-        def __init__(self, toml_file: 'TomlFile', key: str | None = None, old: TOML_VALUE | None = None, new: TOML_VALUE | None = None):
-            super().__init__(toml_file=toml_file)
-            self.key: str = self._SetKey(key)
+    class Get(KeyAccess):
+        """Value is given."""
+        __slots__ = ('toml_file', 'key', 'value')
+
+        def __init__(self, toml_file: 'TomlFile', key: str | None = None, value: TOML_VALUE | None = None) -> None:
+            super().__init__(toml_file=toml_file, key=key)
+            self.value = value
+
+    class Set(KeyAccess):
+        """Value is set."""
+        __slots__ = ('toml_file', 'key', 'old', 'new')
+
+        def __init__(self, toml_file: 'TomlFile', key: str | None = None, old: TOML_VALUE | None = None, new: TOML_VALUE | None = None) -> None:
+            super().__init__(toml_file=toml_file, key=key)
             self.old: TOML_VALUE | None = old
             self.new: TOML_VALUE | None = new
 
@@ -101,7 +112,7 @@ class TomlEvents:
         """General Failure."""
         __slots__ = ('failure',)
 
-        def __init__(self, toml_file: 'TomlFile', failure: str):
+        def __init__(self, toml_file: 'TomlFile', failure: str) -> None:
             super().__init__(toml_file=toml_file)
             self.failure = failure
 
@@ -111,11 +122,11 @@ class BetterTomlDecoder(toml.TomlPreserveCommentDecoder):
 
     With native support for pathlib :py:class:`Path` values; not abandoning the TOML specification.
     """
-    def load_value(self, v: str, strictly_valid=True) -> tuple[Any, str | bool]:
+    def load_value(self, v: str, strictly_valid=True) -> tuple[Any, str]:
         """If the value is a string and starts with the SPECIAL_PATH_PREFIX, load the value enclosed in quotes as a :py:class:`Path`."""
         if v[1:].startswith(SPECIAL_PATH_PREFIX):
-            v = Path(v[1:].removeprefix(SPECIAL_PATH_PREFIX)[:-1])
-            return v, strictly_valid
+            v_path = Path(v[1:].removeprefix(SPECIAL_PATH_PREFIX)[:-1])
+            return v_path, 'path'
         return super().load_value(v=v, strictly_valid=strictly_valid)
 
 
@@ -149,12 +160,12 @@ class TomlFile:
 
     Houses an :py:class:`EventBus` that allows you to subscribe Callables to changes in configuration.
     """
-    EventBus('settings')
 
-    def __init__(self, path: Path | str, default: dict[str, TOML_VALUE] | None = None) -> None:
-        self.path = path
+    def __init__(self, path: Path | str, default: dict[str, TOML_VALUE | CommentValue] | None = None) -> None:
+        self._path: Path = Path(path)
         # FIXME: Default not working as expected during import
         self._data: dict[str, TOML_VALUE | CommentValue] = default if default is not None else {}
+        self.event_bus: EventBus = EventBus()
         if self.reload() is False:
             warnings.warn(f'Could not load TOML file {self.path} on initialization.')
 
@@ -179,8 +190,8 @@ class TomlFile:
         if not path:
             raise ValueError('Path can not be an empty string.')
 
-        scope = self._data
-        paths = path.split('/')
+        scope: dict = self._data
+        paths: list[str] = path.split('/')
 
         if len(paths) > 1:
             for i, key in enumerate(paths):
@@ -221,7 +232,7 @@ class TomlFile:
         if isinstance(val, CommentValue):
             val = val.val
 
-        EventBus['settings'].fire(TomlEvents.Get(self, key, val))
+        self.event_bus.fire(TomlEvents.Get(self, key, val))
 
         return val
 
@@ -246,16 +257,16 @@ class TomlFile:
 
         scope[path] = value
 
-        EventBus['settings'].fire(TomlEvents.Set(self, key, prev_val, value))
+        self.event_bus.fire(TomlEvents.Set(self, key, prev_val, value.val if isinstance(value, CommentValue) else value))
 
     def save(self) -> bool:
         """Save current settings to self.path."""
-        EventBus['settings'].fire(TomlEvents.Save(self))
+        self.event_bus.fire(TomlEvents.Save(self))
         return self.export_to(self.path)
 
     def reload(self) -> bool:
         """Reset settings to settings stored in self.path."""
-        EventBus['settings'].fire(TomlEvents.Reload(self))
+        self.event_bus.fire(TomlEvents.Reload(self))
         return self.import_from(self.path, update=True)
 
     def export_to(self, path: Path | str) -> bool:
@@ -263,16 +274,16 @@ class TomlFile:
 
         :return: True if successful, otherwise False.
         """
-        # TODO: upgrade similarly to import_from
         path = Path(path)  # Make sure path is of type Path
         if path.parent.is_dir():
             with path.open(mode='w', encoding='utf8') as file:
                 toml.dump(self._data, file, encoder=BetterTomlEncoder())
 
-            EventBus['settings'].fire(TomlEvents.Export(self))
+            self.event_bus.fire(TomlEvents.Export(self))
+            self.event_bus.fire(TomlEvents.Get(self))
             return True
 
-        EventBus['settings'].fire(TomlEvents.Fail(self, 'export'))
+        self.event_bus.fire(TomlEvents.Fail(self, 'export'))
         return False
 
     def import_from(self, path: Path | str, update: bool = False) -> bool:
@@ -294,12 +305,12 @@ class TomlFile:
                 pass  # Pass to end of function, to fail.
 
             else:
-                EventBus['settings'].fire(TomlEvents.Import(self))
-                EventBus['settings'].fire(TomlEvents.Set(self))
+                self.event_bus.fire(TomlEvents.Import(self))
+                self.event_bus.fire(TomlEvents.Set(self))
                 return True
 
         # If failed:
-        EventBus['settings'].fire(TomlEvents.Fail(self, 'import'))
+        self.event_bus.fire(TomlEvents.Fail(self, 'import'))
         return False
 
 
